==> qt6-qtmultimedia-6.7.3.tgz: qt6/lib/cmake/Qt6QGstreamerMediaPluginImplPrivate/Qt6QGstreamerMediaPluginImplPrivateDependencies.cmake <==
# Copyright (C) 2024 The Qt Company Ltd.
# SPDX-License-Identifier: BSD-3-Clause

# Make sure Qt6 is found before anything else.
set(Qt6QGstreamerMediaPluginImplPrivate_FOUND FALSE)

if("${_qt_cmake_dir}" STREQUAL "")
    set(_qt_cmake_dir "${QT_TOOLCHAIN_RELOCATABLE_CMAKE_DIR}")
endif()
set(__qt_use_no_default_path_for_qt_packages "NO_DEFAULT_PATH")
if(QT_DISABLE_NO_DEFAULT_PATH_IN_QT_PACKAGES)
    set(__qt_use_no_default_path_for_qt_packages "")
endif()

# Don't propagate REQUIRED so we don't immediately FATAL_ERROR, rather let the find_dependency calls
# set _NOT_FOUND_MESSAGE which will be displayed by the includer of the Dependencies file.
set(${CMAKE_FIND_PACKAGE_NAME}_FIND_REQUIRED FALSE)

if(NOT Qt6_FOUND)
    find_dependency(Qt6 6.7.3
        PATHS
            ${QT_BUILD_CMAKE_PREFIX_PATH}
            "${CMAKE_CURRENT_LIST_DIR}/.."
            "${_qt_cmake_dir}"
            ${_qt_additional_packages_prefix_paths}
        ${__qt_use_no_default_path_for_qt_packages}
    )
endif()


# note: _third_party_deps example: "ICU\\;FALSE\\;1.0\\;i18n uc data;ZLIB\\;FALSE\\;\\;"
set(__qt_QGstreamerMediaPluginImplPrivate_third_party_deps "GStreamer\;FALSE\;\;\;;GStreamer\;FALSE\;\;App\;;GStreamer\;FALSE\;\;\;Photography")
_qt_internal_find_third_party_dependencies("QGstreamerMediaPluginImplPrivate" __qt_QGstreamerMediaPluginImplPrivate_third_party_deps)

# Find Qt tool package.
set(__qt_QGstreamerMediaPluginImplPrivate_tool_deps "")
_qt_internal_find_tool_dependencies("QGstreamerMediaPluginImplPrivate" __qt_QGstreamerMediaPluginImplPrivate_tool_deps)

# note: target_deps example: "Qt6Core\;5.12.0;Qt6Gui\;5.12.0"
set(__qt_QGstreamerMediaPluginImplPrivate_target_deps "Qt6Multimedia\;6.7.3;Qt6Core\;6.7.3")
set(__qt_QGstreamerMediaPluginImplPrivate_find_dependency_paths "${CMAKE_CURRENT_LIST_DIR}/.." "${_qt_cmake_dir}")
_qt_internal_find_qt_dependencies("QGstreamerMediaPluginImplPrivate" __qt_QGstreamerMediaPluginImplPrivate_target_deps
                                  __qt_QGstreamerMediaPluginImplPrivate_find_dependency_paths)

set(_Qt6QGstreamerMediaPluginImplPrivate_MODULE_DEPENDENCIES "Multimedia;Core")
set(Qt6QGstreamerMediaPluginImplPrivate_FOUND TRUE)

==> qt6-qtmultimedia-6.8.1.tgz: qt6/lib/cmake/Qt6QGstreamerMediaPluginImplPrivate/Qt6QGstreamerMediaPluginImplPrivateDependencies.cmake <==
# Copyright (C) 2024 The Qt Company Ltd.
# SPDX-License-Identifier: BSD-3-Clause

# Make sure Qt6 is found before anything else.
set(Qt6QGstreamerMediaPluginImplPrivate_FOUND FALSE)

if("${_qt_cmake_dir}" STREQUAL "")
    set(_qt_cmake_dir "${QT_TOOLCHAIN_RELOCATABLE_CMAKE_DIR}")
endif()
set(__qt_use_no_default_path_for_qt_packages "NO_DEFAULT_PATH")
if(QT_DISABLE_NO_DEFAULT_PATH_IN_QT_PACKAGES)
    set(__qt_use_no_default_path_for_qt_packages "")
endif()

# Don't propagate REQUIRED so we don't immediately FATAL_ERROR, rather let the find_dependency calls
# set _NOT_FOUND_MESSAGE which will be displayed by the includer of the Dependencies file.
set(${CMAKE_FIND_PACKAGE_NAME}_FIND_REQUIRED FALSE)

if(NOT Qt6_FOUND)
    find_dependency(Qt6 6.8.1
        PATHS
            ${QT_BUILD_CMAKE_PREFIX_PATH}
            "${CMAKE_CURRENT_LIST_DIR}/.."
            "${_qt_cmake_dir}"
            ${_qt_additional_packages_prefix_paths}
        ${__qt_use_no_default_path_for_qt_packages}
    )
endif()


# note: _third_party_deps example: "ICU\\;FALSE\\;1.0\\;i18n uc data;ZLIB\\;FALSE\\;\\;"
set(__qt_QGstreamerMediaPluginImplPrivate_third_party_deps "GStreamer\;FALSE\;1.20\;\;;GStreamer\;FALSE\;1.20\;App\;;GStreamer\;FALSE\;1.20\;Play\;;GStreamer\;FALSE\;1.20\;\;Photography;WrapPulseAudio\;FALSE\;\;\;")
set(__qt_QGstreamerMediaPluginImplPrivate_third_party_package_GStreamer_provided_targets "GStreamer::GStreamer")
set(__qt_QGstreamerMediaPluginImplPrivate_third_party_package_GStreamer-App_provided_targets "GStreamer::App")
set(__qt_QGstreamerMediaPluginImplPrivate_third_party_package_GStreamer-Play_provided_targets "GStreamer::Play")
set(__qt_QGstreamerMediaPluginImplPrivate_third_party_package_GStreamer-Photography_provided_targets "GStreamer::Photography")
set(__qt_QGstreamerMediaPluginImplPrivate_third_party_package_WrapPulseAudio_provided_targets "WrapPulseAudio::WrapPulseAudio")

_qt_internal_find_third_party_dependencies("QGstreamerMediaPluginImplPrivate" __qt_QGstreamerMediaPluginImplPrivate_third_party_deps)

# Find Qt tool package.
set(__qt_QGstreamerMediaPluginImplPrivate_tool_deps "")
_qt_internal_find_tool_dependencies("QGstreamerMediaPluginImplPrivate" __qt_QGstreamerMediaPluginImplPrivate_tool_deps)

# note: target_deps example: "Qt6Core\;5.12.0;Qt6Gui\;5.12.0"
set(__qt_QGstreamerMediaPluginImplPrivate_target_deps "Qt6Multimedia\;6.8.1;Qt6Core\;6.8.1")
set(__qt_QGstreamerMediaPluginImplPrivate_find_dependency_paths "${CMAKE_CURRENT_LIST_DIR}/.." "${_qt_cmake_dir}")
_qt_internal_find_qt_dependencies("QGstreamerMediaPluginImplPrivate" __qt_QGstreamerMediaPluginImplPrivate_target_deps
                                  __qt_QGstreamerMediaPluginImplPrivate_find_dependency_paths)

set(_Qt6QGstreamerMediaPluginImplPrivate_MODULE_DEPENDENCIES "Multimedia;Core")
set(Qt6QGstreamerMediaPluginImplPrivate_FOUND TRUE)
